@@ -11,7 +11,10 @@ test_that("read_aircrafts", {
 
   # (default), one month, basica, progress
   testthat::expect_true(is(read_aircrafts(showProgress = FALSE), "data.table"))
-  testthat::expect_true(is(read_aircrafts(), "data.table"))
+  testthat::expect_true(is(read_aircrafts(showProgress = TRUE), "data.table"))
+
+  # test columns are correct
+  testthat::expect_equal(names(read_aircrafts())[1], 'MARCA')
 })
 
 
@@ -20,5 +23,7 @@ test_that("read_aircrafts", {
 
   testthat::expect_error(read_aircrafts(showProgress='banana'))
   testthat::expect_error(read_aircrafts(showProgress=NULL))
+  testthat::expect_error(read_aircrafts(showProgress=3))
+  testthat::expect_error(read_aircrafts(a=NULL))
 
 })
